==> cloud-3.2.0.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Traits/AwsCloudEntityCheckTrait.php <==
<?php

namespace Drupal\aws_cloud\Traits;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * The trait checking permission.
 */
trait AwsCloudEntityCheckTrait {
  /**
   * Redirect render object.
   *
   * @var \Symfony\Component\HttpFoundation\RedirectResponse
   */
  protected $redirectUrl;

  /**
   * Helper to check if entity exists in submitForm().
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Form state handles redirect.
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   Process non-property entity.
   *
   * @return bool
   *   If entity does not exit, return FALSE and redirect to list page.
   */
  protected function updateEntitySubmitForm(FormStateInterface $form_state, EntityInterface $entity) {
    $ec2Service = \Drupal::service('aws_cloud.ec2');
    $ec2Service->setCloudContext($entity->getCloudContext());

    if ($ec2Service->updateSingleEntity($entity, TRUE) === FALSE) {
      \Drupal::messenger()->addError($this->t('The @label %name has already been deleted.', [
        '@label' => $entity->getEntityType()->getSingularLabel(),
        '%name' => $entity->getName(),
      ]));
      $form_state->setRedirect("view.{$entity->getEntityTypeId()}.list", [
        'cloud_context' => $entity->getCloudContext(),
      ]);
      return FALSE;
    }
    return TRUE;
  }

  /**
   * Helper to check if entity exists in buildForm().
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   Process non-property entity.
   *
   * @return bool
   *   If entity exist, return TRUE.
   *   If entity does not exist, return FALSE.
   */
  protected function updateEntityBuildForm(EntityInterface $entity) {
    $ec2Service = \Drupal::service('aws_cloud.ec2');
    $ec2Service->setCloudContext($entity->getCloudContext());

    if ($ec2Service->updateSingleEntity($entity) === FALSE) {
      if ($entity->getEntityTypeId() !== 'aws_cloud_vpc_peering_connection') {
        \Drupal::messenger()->addError($this->t('The @label %name has already been deleted.', [
          '@label' => $entity->getEntityType()->getSingularLabel(),
          '%name' => $entity->getName(),
        ]));
      }
      $url = Url::fromRoute(
        "entity.{$entity->getEntityTypeId()}.collection",
        ['cloud_context' => $entity->getCloudContext()]
      );
      $this->setRedirectUrl($url->setAbsolute(TRUE)->toString());
      return FALSE;
    }
    return TRUE;
  }

  /**
   * Set redirect render.
   *
   * @param string $url
   *   Redirect url.
   */
  protected function setRedirectUrl($url) {
    $this->redirectUrl = new RedirectResponse($url);
  }

}

==> cloud-4.1.0.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Traits/AwsCloudEntityCheckTrait.php <==
<?php

namespace Drupal\aws_cloud\Traits;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * The trait checking permission.
 */
trait AwsCloudEntityCheckTrait {
  /**
   * Redirect render object.
   *
   * @var \Symfony\Component\HttpFoundation\RedirectResponse
   */
  protected $redirectUrl;

  /**
   * Helper to check if entity exists in submitForm().
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Form state handles redirect.
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   Process non-property entity.
   *
   * @return bool
   *   If entity does not exit, return FALSE and redirect to list page.
   */
  protected function updateEntitySubmitForm(FormStateInterface $form_state, EntityInterface $entity): bool {
    $ec2Service = \Drupal::service('aws_cloud.ec2');
    $ec2Service->setCloudContext($entity->getCloudContext());

    if ($ec2Service->updateSingleEntity($entity, TRUE) === FALSE) {
      \Drupal::messenger()->addError($this->t('The @label %name has already been deleted.', [
        '@label' => $entity->getEntityType()->getSingularLabel(),
        '%name' => $entity->getName(),
      ]));
      $form_state->setRedirect("view.{$entity->getEntityTypeId()}.list", [
        'cloud_context' => $entity->getCloudContext(),
      ]);
      return FALSE;
    }
    return TRUE;
  }

  /**
   * Helper to check if entity exists in buildForm().
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   Process non-property entity.
   *
   * @return bool
   *   If entity exist, return TRUE.
   *   If entity does not exist, return FALSE.
   */
  protected function updateEntityBuildForm(EntityInterface $entity): bool {
    $ec2Service = \Drupal::service('aws_cloud.ec2');
    $ec2Service->setCloudContext($entity->getCloudContext());

    if ($ec2Service->updateSingleEntity($entity) === FALSE) {
      if ($entity->getEntityTypeId() !== 'aws_cloud_vpc_peering_connection') {
        \Drupal::messenger()->addError($this->t('The @label %name has already been deleted.', [
          '@label' => $entity->getEntityType()->getSingularLabel(),
          '%name' => $entity->getName(),
        ]));
      }
      $url = Url::fromRoute(
        "entity.{$entity->getEntityTypeId()}.collection",
        ['cloud_context' => $entity->getCloudContext()]
      );
      $this->setRedirectUrl($url->setAbsolute(TRUE)->toString());
      return FALSE;
    }
    return TRUE;
  }

  /**
   * Set redirect render.
   *
   * @param string $url
   *   Redirect URL.
   */
  protected function setRedirectUrl($url): void {
    $this->redirectUrl = new RedirectResponse($url);
  }

}
